@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 from __future__ import print_function
 
-VERSION = '0.4.9'
+VERSION = '0.4.10'
 
 import os
 import sys
@@ -476,7 +476,7 @@ def easy_roll(raw_args):
     kernel.extract()
     if args.patch:
         print('Dropping into a bash shell for patching; `exit` to continue')
-        system('bash')
+        os.system('bash')
     kernel.configure()
     if modify:
         kernel.modify()
